global\_logger package
======================

Submodules
----------

global\_logger.global\_logger module
------------------------------------

.. automodule:: global_logger.global_logger
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: global_logger
   :members:
   :undoc-members:
   :show-inheritance:
